# vs-deinterlace

### VapourSynth deinterlacing and interlaced/telecined content helper functions
<br>

You can find support in the [IEW Discord server](https://discord.gg/qxTxVJGtst).
<br><br>
## How to install

Install `vsdeinterlace` with the following command:

```sh
$ pip install vsdeinterlace
```

Or if you want the latest git version, install it with this command:

```sh
$ pip install git+https://github.com/Irrational-Encoding-Wizardry/vs-deinterlace.git
```
